@@ -12,12 +12,11 @@ from unittest import TestCase
 from PyMetabuilder import MetaBuilder
 
 
-class KiteBuilder(MetaBuilder.MetaBuilder):
-
+class KiteBuilder(MetaBuilder):
     KITE = 'Kite'
 
     def __init__(self):
-        MetaBuilder.MetaBuilder.__init__(self)
+        MetaBuilder.__init__(self)
         self.model_by_name(self.KITE)
         self.property("design", one_of=["Indoor", "Water Kite", "Kythoon"])
         self.property("line_material", type=str)
@@ -25,24 +24,23 @@ class KiteBuilder(MetaBuilder.MetaBuilder):
 
 
 class TestKiteMetaBuilder(TestCase):
-
     def setUp(self):
         self.kiteBuilder = KiteBuilder()
         self.kiteBuilder.design = "Indoor"
-        self.kite =self.get_kite_instance()
+        self.kite = self.get_kite_instance()
 
     def get_kite_instance(self):
         return self.kiteBuilder.build()
 
     def test_class(self):
-        self.assertEqual(self.kiteBuilder.KITE,self.get_kite_instance().__class__.__name__)
+        self.assertEqual(self.kiteBuilder.KITE, self.get_kite_instance().__class__.__name__)
 
     def test_attributes(self):
-        self.assertEqual('Indoor',self.kite.design)
+        self.assertEqual('Indoor', self.kite.design)
 
     def test_set_attribute(self):
-        self.kite.line_material='Linen'
-        self.assertEqual('Linen',self.kite.line_material)
+        self.kite.line_material = 'Linen'
+        self.assertEqual('Linen', self.kite.line_material)
 
     def test_invalid_set_attribute(self):
-        self.assertRaises(TypeError,self.kite.line_material,2)
\ No newline at end of file
+        self.assertRaises(TypeError, self.kite.line_material, 2)
\ No newline at end of file
