@@ -9,17 +9,17 @@
 
 """
 from unittest import TestCase
-from PyMetabuilder import MetaBuilder
+from PyMetabuilder import *
 
 
 class Person(object):
     pass
 
 
-class PersonMetaBuilder(MetaBuilder.MetaBuilder):
+class PersonMetaBuilder(MetaBuilder):
 
     def __init__(self):
-        MetaBuilder.MetaBuilder.__init__(self)
+        MetaBuilder.__init__(self)
         self.model(Person)
         self.property('name')
         self.property('age', type=int)
@@ -37,13 +37,13 @@ class PyMetaBuilderTest(TestCase):
         self.personMeta = PersonMetaBuilder()
 
     def test_hierarchy(self):
-        self.assertIsInstance(self.personMeta, MetaBuilder.MetaBuilder)
+        self.assertIsInstance(self.personMeta, MetaBuilder)
 
     def test_should_able_to_add_model(self):
         self.assertEqual(Person, self.personMeta.__getattribute__("_model"))
 
     def test_check_property_set(self):
-        self.assertIn('validate_type_age', MetaBuilder.getMethods(self.personMeta))
+        self.assertIn('validate_type_age', getMethods(self.personMeta))
 
     def test_get_validators_name(self):
         val = self.personMeta._getValidatorsByName('age')
@@ -71,7 +71,7 @@ class PyMetaBuilderTest(TestCase):
     def test_incorrect_attribute_options(self):
         def setJob():
             self.personMeta.job = 'ssse'
-        self.assertRaises(MetaBuilder.OptionValueError, setJob)
+        self.assertRaises(OptionValueError, setJob)
 
     def test_correct_custom_validator(self):
         self.personMeta.height = 2
@@ -80,7 +80,7 @@ class PyMetaBuilderTest(TestCase):
     def test_correct_custom_validator(self):
         def setMyHeight():
             self.personMeta.height = 22
-        self.assertRaises(MetaBuilder.ValidatorError, setMyHeight)
+        self.assertRaises(ValidatorError, setMyHeight)
 
     def test_required_not_filled(self):
         def build_without_required():
@@ -91,7 +91,7 @@ class PyMetaBuilderTest(TestCase):
     def test_reserved_attribute(self):
         def reserved_word():
             self.personMeta.property("_model")
-        self.assertRaises(MetaBuilder.MetaBuilderError, reserved_word)
+        self.assertRaises(MetaBuilderError, reserved_word)
 
     def test_build(self):
         self.personMeta.age = 50
