@@ -9,7 +9,7 @@
 
 """
 from unittest import TestCase
-from PyMetabuilder import MetaBuilder
+from PyMetabuilder import MetaBuilder, ValidatorError
 
 
 class Logo:
@@ -20,20 +20,30 @@ class CreditCard:
     pass
 
 
-class CreditCardMetaBuilder(MetaBuilder.MetaBuilder):
+class CreditCardMetaBuilder(MetaBuilder):
 
     def __init__(self):
-        MetaBuilder.MetaBuilder.__init__(self)
+        MetaBuilder.__init__(self)
         self.model(CreditCard)
         self.property("ccnumber", type=str, length=16, required=True)
         self.property("ccName", type=str, required=True)
         self.property("extraLogo", type=Logo)
 
+class CreditCardCascadeMetaBuilder(MetaBuilder):
+
+    def __init__(self):
+        MetaBuilder.__init__(self)
+        self.model(CreditCard)\
+        .property("ccnumber", type=str, length=16, required=True)\
+        .property("ccName", type=str, required=True)\
+        .property("extraLogo", type=Logo)
+
 
 class TestCreditCardMetaBuilder(TestCase):
 
     def setUp(self):
         self.cardBuilder = CreditCardMetaBuilder()
+        self.cascadeCardBuilder = CreditCardCascadeMetaBuilder()
 
     def CCBuild(self):
         creditcard = self.cardBuilder.build()
@@ -48,4 +58,12 @@ class TestCreditCardMetaBuilder(TestCase):
         self.assertRaises(AttributeError,self.cardBuilder.build)
 
     def test_invalid_length_build(self):
-        self.assertRaises(MetaBuilder.ValidatorError,self.cardBuilder.ccnumber,"543042222333444")
\ No newline at end of file
+        self.assertRaises(ValidatorError,self.cardBuilder.ccnumber,"543042222333444")
+
+    def test_normal_build_cascade(self):
+        self.cascadeCardBuilder.ccnumber = "5430422223333444"
+        self.cascadeCardBuilder.ccName = 'John Doe'
+        self.cascadeCardBuilder.build()
+
+    def test_invalid_length_build_cascade(self):
+        self.assertRaises(ValidatorError,self.cascadeCardBuilder.ccnumber,"543042222333444")
\ No newline at end of file
